@@ -26,9 +26,9 @@ use vars qw($VERSION
             $HTML_KEY
             @EXPORT_OK
             );
-@EXPORT_OK = qw(conf_read conf_write);
+@EXPORT_OK = qw(conf_read conf_write in_cache);
 
-$VERSION = '2.03';
+$VERSION = '2.04';
 
 $DEFAULT_EXT = 'conf';
 
@@ -583,47 +583,52 @@ sub write_handler_html {
 ###----------------------------------------------------------------###
 
 sub preload_files {
-  my $self  = shift;
-  my $paths = shift || $self->paths;
-  require File::Find;
+    my $self  = shift;
+    my $paths = shift || $self->paths;
 
-  ### what extensions do we look for
-  my %EXT;
-  if ($self->{handler}) {
-    if (UNIVERSAL::isa($self->{handler},'HASH')) {
-      %EXT = %{ $self->{handler} };
-    }
-  } else {
-    %EXT = %EXT_READERS;
-    if (! $self->{html_key} && ! $HTML_KEY) {
-      delete $EXT{$_} foreach qw(html htm);
-    }
-  }
-  return if ! keys %EXT;
-
-  ### look in the paths for the files
-  foreach my $path (ref($paths) ? @$paths : $paths) {
-    $path =~ s|//+|/|g;
-    $path =~ s|/$||;
-    next if exists $CACHE{$path};
-    if (-f $path) {
-      my $ext = ($path =~ /\.(\w+)$/) ? $1 : '';
-      next if ! $EXT{$ext};
-      $CACHE{$path} = $self->read($path);
-    } elsif (-d _) {
-      $CACHE{$path} = 1;
-      File::Find::find(sub {
-        return if exists $CACHE{$File::Find::name};
-        return if $File::Find::name =~ m|/CVS/|;
-        return if ! -f;
-        my $ext = (/\.(\w+)$/) ? $1 : '';
-        return if ! $EXT{$ext};
-        $CACHE{$File::Find::name} = $self->read($File::Find::name);
-      }, "$path/");
+    ### what extensions do we look for
+    my %EXT;
+    if ($self->{'handler'}) {
+        if (UNIVERSAL::isa($self->{'handler'},'HASH')) {
+            %EXT = %{ $self->{'handler'} };
+        }
     } else {
-      $CACHE{$path} = 0;
+        %EXT = %EXT_READERS;
+        if (! $self->{'html_key'} && ! $HTML_KEY) {
+            delete $EXT{$_} foreach qw(html htm);
+        }
     }
-  }
+    return if ! keys %EXT;
+
+    ### look in the paths for the files
+    foreach my $path (ref($paths) ? @$paths : $paths) {
+        $path =~ s|//+|/|g;
+        $path =~ s|/$||;
+        next if exists $CACHE{$path};
+        if (-f $path) {
+            my $ext = ($path =~ /\.(\w+)$/) ? $1 : '';
+            next if ! $EXT{$ext};
+            $CACHE{$path} = $self->read($path);
+        } elsif (-d _) {
+            $CACHE{$path} = 1;
+            require File::Find;
+            File::Find::find(sub {
+                return if exists $CACHE{$File::Find::name};
+                return if $File::Find::name =~ m|/CVS/|;
+                return if ! -f;
+                my $ext = (/\.(\w+)$/) ? $1 : '';
+                return if ! $EXT{$ext};
+                $CACHE{$File::Find::name} = $self->read($File::Find::name);
+            }, "$path/");
+        } else {
+            $CACHE{$path} = 0;
+        }
+    }
+}
+
+sub in_cache {
+    my ($self, $file) = (@_ == 2) ? @_ : (undef, shift());
+    return exists($CACHE{$file}) || 0;
 }
 
 ###----------------------------------------------------------------###
@@ -634,43 +639,53 @@ __END__
 
 =head1 SYNOPSIS
 
-  my $cob = CGI::Ex::Conf->new;
+    use CGI::Ex::Conf qw(conf_read conf_write);
 
-  my $full_path_to_file = "/tmp/foo.val"; # supports ini, sto, val, pl, xml
-  my $hash = $cob->read($file);
+    my $hash = conf_read("/tmp/foo.yaml");
 
-  local $cob->{default_ext} = 'conf'; # default anyway
+    conf_write("/tmp/foo.yaml", {key1 => $val1, key2 => $val2});
 
 
-  my @paths = qw(/tmp, /home/pauls);
-  local $cob->{paths} = \@paths;
-  my $hash = $cob->read('My::NameSpace');
-  # will look in /tmp/My/NameSpace.conf and /home/pauls/My/NameSpace.conf
+    ### OOP interface
 
-  my $hash = $cob->read('My::NameSpace', {paths => ['/tmp']});
-  # will look in /tmp/My/NameSpace.conf
+    my $cob = CGI::Ex::Conf->new;
+
+    my $full_path_to_file = "/tmp/foo.val"; # supports ini, sto, val, pl, xml
+    my $hash = $cob->read($file);
+
+    local $cob->{default_ext} = 'conf'; # default anyway
 
 
-  local $cob->{directive} = 'MERGE';
-  my $hash = $cob->read('FooSpace');
-  # OR #
-  my $hash = $cob->read('FooSpace', {directive => 'MERGE'});
-  # will return merged hashes from /tmp/FooSpace.conf and /home/pauls/FooSpace.conf
-  # immutable keys are preserved from originating files
+    my @paths = qw(/tmp, /home/pauls);
+    local $cob->{paths} = \@paths;
+    my $hash = $cob->read('My::NameSpace');
+    # will look in /tmp/My/NameSpace.conf and /home/pauls/My/NameSpace.conf
 
 
-  local $cob->{directive} = 'FIRST';
-  my $hash = $cob->read('FooSpace');
-  # will return values from first found file in the path.
+    my $hash = $cob->read('My::NameSpace', {paths => ['/tmp']});
+    # will look in /tmp/My/NameSpace.conf
 
 
-  local $cob->{directive} = 'LAST'; # default behavior
-  my $hash = $cob->read('FooSpace');
-  # will return values from last found file in the path.
+    local $cob->{directive} = 'MERGE';
+    my $hash = $cob->read('FooSpace');
+    # OR #
+    my $hash = $cob->read('FooSpace', {directive => 'MERGE'});
+    # will return merged hashes from /tmp/FooSpace.conf and /home/pauls/FooSpace.conf
+    # immutable keys are preserved from originating files
 
 
-  ### manipulate $hash
-  $cob->write('FooSpace'); # will write it out the changes
+    local $cob->{directive} = 'FIRST';
+    my $hash = $cob->read('FooSpace');
+    # will return values from first found file in the path.
+
+
+    local $cob->{directive} = 'LAST'; # default behavior
+    my $hash = $cob->read('FooSpace');
+    # will return values from last found file in the path.
+
+
+    ### manipulate $hash
+    $cob->write('FooSpace'); # will write it out the changes
 
 =head1 DESCRIPTION
 
@@ -688,7 +703,7 @@ Oh - and it writes too.
 
 =over 4
 
-=item C<-E<gt>read_ref>
+=item C<read_ref>
 
 Takes a file and optional argument hashref.  Figures out the type
 of handler to use to read the file, reads it and returns the ref.
@@ -696,7 +711,7 @@ If you don't need the extended merge functionality, or key fallback,
 or immutable keys, or path lookup ability - then use this method.
 Otherwise - use ->read.
 
-=item C<-E<gt>read>
+=item C<read>
 
 First argument may be either a perl data structure, yaml string, a
 full filename, or a file "namespace".
@@ -754,13 +769,13 @@ The immutable defaults may be overriden using $IMMUTABLE_QR and $IMMUTABLE_KEY.
 
 Errors during read die.  If the file does not exist undef is returned.
 
-=item C<-E<gt>write_ref>
+=item C<write_ref>
 
 Takes a file and the reference to be written.  Figures out the type
 of handler to use to write the file and writes it. If you used the ->read_ref
 use this method.  Otherwise, use ->write.
 
-=item C<-E<gt>write>
+=item C<write>
 
 Allows for writing back out the information read in by ->read.  If multiple
 paths where used - the directive 'FIRST' will write the changes to the first
@@ -769,7 +784,7 @@ immutable keys, then those keys are removed before writing.
 
 Errors during write die.
 
-=item C<-E<gt>preload_files>
+=item C<preload_files>
 
 Arguments are file(s) and/or directory(s) to preload.  preload_files will
 loop through the arguments, find the files that exist, read them in using
@@ -778,6 +793,36 @@ in %CACHE.  Directories are spidered for file extensions which match those
 listed in %EXT_READERS.  This is useful for a server environment where CPU
 may be more precious than memory.
 
+=item C<in_cache>
+
+Allow for testing if a particular filename is registered in the %CACHE - typically
+from a preload_files call.  This is useful when building wrappers around the
+conf_read and conf_write method calls.
+
+=back
+
+=head1 FUNCTIONS
+
+=over4
+
+=item conf_read
+
+Takes a filename.  Returns the read contents of that filename.  The handler
+to use is based upon the extention on the file.
+
+    my $hash = conf_read('/tmp/foo.yaml');
+
+    my $hash = conf_read('/tmp/foo', {file_type => 'yaml'});
+
+Takes a filename and a data structure.  Writes the data to the filename.  The handler
+to use is based upon the extention on the file.
+
+    conf_write('/tmp/foo.yaml', \%hash);
+
+    conf_write('/tmp/foo', \%hash, {file_type => 'yaml'});
+
+=back
+
 =head1 FILETYPES
 
 CGI::Ex::Conf supports the files found in %EXT_READERS by default.
