@@ -4,7 +4,7 @@
 *  Based upon CGI/Ex/Validate.pm v1.14 from Perl                     *
 *  For instructions on usage, see perldoc of CGI::Ex::Validate       *
 ***----------------------------------------------------------------**/
-// $Revision: 1.35 $
+// $Revision: 1.36 $
 
 function Validate () {
  this.error             = vob_error;
@@ -292,7 +292,8 @@ function vob_validate_buddy (form, field, field_val, N_level, ifs_match) {
    for (var i = 0; i < tests.length; i ++) {
      var el = form[field];
      var type = el.type;
-     if (type && (type == 'hidden' || type == 'password' || type == 'text' || type == 'textarea' || type == 'submit')) el.value = values[0] = field_val[tests[i]];
+     if (type && (type == 'hidden' || type == 'password' || type == 'text' || type == 'textarea' || type == 'submit'))
+       el.value = values[0] = '' + field_val[tests[i]];
    }
  }
 
